@@ -40,7 +40,7 @@ adapt_draw_random_pattern ()
 	gunichar text[WORDS * (MAX_WORD_LEN + 1) + 3];
 	gunichar word[MAX_WORD_LEN + 1];
 	gboolean special;
-	gboolean word_ok;
+	gboolean word_ok = FALSE;
 
 	hlp = main_preferences_get_string ("interface", "language");
 
@@ -49,7 +49,7 @@ adapt_draw_random_pattern ()
 		gtk_widget_show (get_wg ("togglebutton_toomuch_errors"));
 	else
 		gtk_widget_hide (get_wg ("togglebutton_toomuch_errors"));
-	special = special && gtk_toggle_button_get_active (get_wg ("togglebutton_toomuch_errors"));
+	special = special && gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (get_wg ("togglebutton_toomuch_errors")));
 
 	for (i = 0; i < LINES; i++)
 	{			/* paragraphs per exercise */
