@@ -1526,7 +1526,17 @@ hints_init ()
 	if (hints_is_initialized == TRUE)
 		return;
 
-	tmp_name = g_build_filename (main_path_data (), "fingers_position.txt", NULL);
+	tmp_name = g_build_filename ("/etc/klavaro/fingers_position.txt", NULL);
+	if (!g_file_test (tmp_name, G_FILE_TEST_IS_REGULAR))
+	{
+		g_free (tmp_name);
+		tmp_name = g_build_filename (main_path_user (), "fingers_position.txt", NULL);
+	}
+	if (!g_file_test (tmp_name, G_FILE_TEST_IS_REGULAR))
+	{
+		g_free (tmp_name);
+		tmp_name = g_build_filename (main_path_data (), "fingers_position.txt", NULL);
+	}
 	fh = (FILE *) g_fopen (tmp_name, "r");
 	if (fh)
 	{
