@@ -201,20 +201,14 @@ main_initialize_global_variables ()
 	FILE *fh_to;
 	GDir *kscdir;
 
-	/* Set the home user dir (update to new config dir)
+	/* Set the home user dir
 	 */
-	tmp = g_build_filename (g_get_home_dir (), ".klavaro", NULL);
 	path.user = g_build_filename (g_get_user_config_dir (), "klavaro", NULL);
-	if (g_file_test (tmp, G_FILE_TEST_IS_DIR))
+	if (!g_file_test (path.user, G_FILE_TEST_IS_DIR))
 	{
-		g_mkdir (g_get_user_config_dir (), DIR_PERM);
-		if (g_rename (tmp, path.user) != 0)
-		{
-			g_free (path.user);
-			path.user = g_strdup (tmp);
-		}
+		if (g_mkdir_with_parents (path.user, DIR_PERM) == -1)
+			g_error ("Sorry, not able to create the user config dir: %s", path.user);
 	}
-	g_free (tmp);
 
 	/* Set the home user stats dir (update to new local/share dir)
 	 */
@@ -323,6 +317,49 @@ main_initialize_global_variables ()
 	OTHER_DEFAULT = g_strdup (_("(Default)"));
 }
 
+static void
+main_gtkbuilder_translation_workaround ()
+{
+	gchar *lb;
+	GSList *ls;
+	GSList *it;
+	GtkWidget *wg;
+
+	ls = gtk_builder_get_objects (gui);
+	it = ls;
+	do
+	{
+		if (GTK_OBJECT_TYPE (it->data) == GTK_TYPE_LABEL)
+		{
+			lb = (gchar *) gtk_label_get_label (GTK_LABEL (it->data));
+			if (lb[0] != '\0')
+				gtk_label_set_text_with_mnemonic (GTK_LABEL (it->data), _(lb));
+		}
+		else if (GTK_OBJECT_TYPE (it->data) == GTK_TYPE_ENTRY)
+		{
+			lb = gtk_entry_get_icon_tooltip_text (GTK_ENTRY (it->data), GTK_ENTRY_ICON_SECONDARY);
+			if (lb)
+			{
+				if (lb[0] != '\0')
+					gtk_entry_set_icon_tooltip_text (GTK_ENTRY (it->data), GTK_ENTRY_ICON_SECONDARY, _(lb));
+			}
+		}
+		else if (GTK_OBJECT_TYPE (it->data) == GTK_TYPE_WINDOW)
+			gtk_window_set_title (GTK_WINDOW (it->data), _(gtk_window_get_title (GTK_WINDOW (it->data))));
+
+		if (GTK_IS_WIDGET (it->data))
+		{
+			wg = GTK_WIDGET (it->data);
+			if (gtk_widget_get_has_tooltip (wg))
+				gtk_widget_set_tooltip_text (wg, _(gtk_widget_get_tooltip_text (wg)));
+		}
+
+		it = g_slist_next (it);
+	} while (it);
+
+	g_slist_free (ls);
+}
+
 /*******************************************************************************
  * Initialize some interface widgets
  */
@@ -332,6 +369,11 @@ main_window_init ()
 	gchar *tmp;
 	PangoAttrList *palist;
 
+	/* Workaround to make GtkBuilder translate all text, on Windows :-(
+	 */
+	if (! UNIX_OK)
+		main_gtkbuilder_translation_workaround ();
+
 	/* Set the language
 	 */
 	trans_set_combo_language ();
@@ -425,6 +467,7 @@ main_window_init ()
 			break;
 		}
 	}
+
 }
 
 /*******************************************************************************
@@ -436,11 +479,9 @@ main (int argc, char *argv[])
 	gchar *tmp;
 	gboolean success = FALSE;
 	gboolean show_version = FALSE;
-	gboolean do_admin = FALSE;
 	GOptionContext *opct;
 	GOptionEntry option[] = {
-		{"version", 'v', 0, G_OPTION_ARG_NONE, &show_version, "", NULL},
-		{"admin", 'a', 0, G_OPTION_ARG_NONE, &do_admin, "", NULL},
+		{"version", 'v', 0, G_OPTION_ARG_NONE, &show_version, "Versio", NULL},
 		{NULL}
 	};
 
@@ -466,16 +507,6 @@ main (int argc, char *argv[])
 		return 0;
 	}
 
-	if (do_admin)
-	{
-		main_initialize_global_variables ();
-		curl_ok = curl_global_init (CURL_GLOBAL_WIN32) == CURLE_OK ? TRUE : FALSE;
-		top10_global_rank ();
-		if (curl_ok)
-			curl_global_cleanup ();
-		return 0;
-	}
-
 	curl_ok = curl_global_init (CURL_GLOBAL_WIN32) == CURLE_OK ? TRUE : FALSE;
 
 	main_initialize_global_variables ();	/* Here the locale is got. */
@@ -483,6 +514,8 @@ main (int argc, char *argv[])
 	/* Create all the interface stuff
 	 */
 	gui = gtk_builder_new ();
+	gtk_builder_set_translation_domain (gui, NULL);
+
 	tmp = g_build_filename (main_path_data (), "klavaro.ui", NULL);
 	if (g_file_test (tmp, G_FILE_TEST_IS_REGULAR))
 		success = gtk_builder_add_from_file (gui, tmp, NULL);
