@@ -320,7 +320,8 @@ top10_get_score_file (gboolean locally, gint lang)
 static void
 top10_merge_stats_from_file (gchar * file)
 {
-	gint i, j, n;
+	gint i, j;
+	gint32 n;
 	FILE *fh;
 	Statistics top10;
 
@@ -355,15 +356,16 @@ top10_merge_stats_from_file (gchar * file)
 		}
 
 		/* when */
-		n = fread (&top10.when, sizeof (time_t), 1, fh);
+		//n = fread (&top10.when, sizeof (time_t), 1, fh);
+		n = fread (&top10.when, sizeof (gint32), 1, fh);
 		if (n == 0)
 		{
-			g_message ("Problem: when = %lu", top10.when);
+			g_message ("Problem: when = %li", top10.when);
 			break;
 		}
 
 		/* nchars */
-		n = fread (&top10.nchars, sizeof (gint), 1, fh);
+		n = fread (&top10.nchars, sizeof (gint32), 1, fh);
 		if (n == 0 || top10.nchars < MIN_CHARS_TO_LOG)
 		{
 			g_message ("Problem: nchars = %i, < %i", top10.nchars, MIN_CHARS_TO_LOG);
@@ -403,7 +405,7 @@ top10_merge_stats_from_file (gchar * file)
 		}
 
 		/* name_len */
-		n = fread (&top10.name_len, sizeof (gint), 1, fh);
+		n = fread (&top10.name_len, sizeof (gint32), 1, fh);
 		if (n == 0 || top10.name_len < 0 || top10.name_len > MAX_NAME_LEN)
 		{
 			g_message ("Problem: name_len = %i <> [0, MAX_NAME_LEN]", top10.name_len);
@@ -428,7 +430,8 @@ top10_merge_stats_from_file (gchar * file)
 gboolean
 top10_read_stats_from_file (gboolean locally, gchar * file)
 {
-	gint i, j, n;
+	gint i, j;
+	gint32 n;
 	gboolean success;
 	FILE *fh;
 	Statistics *top10;
@@ -468,15 +471,16 @@ top10_read_stats_from_file (gboolean locally, gchar * file)
 		}
 
 		/* when */
-		n = fread (&top10[i].when, sizeof (time_t), 1, fh);
+		//n = fread (&top10[i].when, sizeof (time_t), 1, fh);
+		n = fread (&top10[i].when, sizeof (gint32), 1, fh);
 		if (n == 0)
 		{
-			g_message ("Problem: when = %lu", top10[i].when);
+			g_message ("Problem: when = %li", top10[i].when);
 			break;
 		}
 
 		/* nchars */
-		n = fread (&top10[i].nchars, sizeof (gint), 1, fh);
+		n = fread (&top10[i].nchars, sizeof (gint32), 1, fh);
 		if (n == 0 || top10[i].nchars < MIN_CHARS_TO_LOG)
 		{
 			g_message ("Problem: nchars = %i, < %i", top10[i].nchars, MIN_CHARS_TO_LOG);
@@ -516,7 +520,7 @@ top10_read_stats_from_file (gboolean locally, gchar * file)
 		}
 
 		/* name_len */
-		n = fread (&top10[i].name_len, sizeof (gint), 1, fh);
+		n = fread (&top10[i].name_len, sizeof (gint32), 1, fh);
 		if (n == 0 || top10[i].name_len < 0 || top10[i].name_len > MAX_NAME_LEN)
 		{
 			g_message ("Problem: name_len = %i <> [0, MAX_NAME_LEN]", top10[i].name_len);
@@ -562,6 +566,7 @@ top10_read_stats (gboolean locally, gint lang)
 		g_message ("Could not read the scores file '%s'.\n Creating a blank one.", tmp);
 		top10_init_stats (locally);
 		top10_write_stats (locally, lang);
+		//top10_show_stat (top10);
 	}
 	g_free (tmp);
 
@@ -584,7 +589,10 @@ top10_read_stats (gboolean locally, gint lang)
 		home = g_dir_open ("/home", 0, NULL);
 	}
 	else
+	{
+		stat_dir = NULL;
 	       	home = NULL;
+	}
 
 	success = FALSE;
 	if (home)
@@ -646,13 +654,14 @@ top10_write_stats (gboolean locally, gint lang)
 		fputc (top10[i].lang[0], fh);
 		fputc (top10[i].lang[1], fh);
 		fputc (top10[i].genv, fh);
-		fwrite (&top10[i].when, sizeof (time_t), 1, fh);
-		fwrite (&top10[i].nchars, sizeof (gint), 1, fh);
+		//fwrite (&top10[i].when, sizeof (time_t), 1, fh);
+		fwrite (&top10[i].when, sizeof (gint32), 1, fh);
+		fwrite (&top10[i].nchars, sizeof (gint32), 1, fh);
 		fwrite (&top10[i].accur, sizeof (gfloat), 1, fh);
 		fwrite (&top10[i].velo, sizeof (gfloat), 1, fh);
 		fwrite (&top10[i].fluid, sizeof (gfloat), 1, fh);
 		fwrite (&top10[i].score, sizeof (gfloat), 1, fh);
-		fwrite (&top10[i].name_len, sizeof (gint), 1, fh);
+		fwrite (&top10[i].name_len, sizeof (gint32), 1, fh);
 		if (top10[i].name && top10[i].name_len > 0)
 			fputs (top10[i].name, fh);
 	}
@@ -864,6 +873,7 @@ top10_global_update (gpointer data)
 	g_free (tmp);
 	g_free (ksc);
 
+
 	if (gtk_combo_box_get_active (GTK_COMBO_BOX (get_wg ("combobox_top10"))) == 0)
 		top10_show_stats (LOCAL);
 	else
@@ -922,7 +932,6 @@ top10_global_publish (gpointer data)
 		tmp = g_strdup ("en");
 	}
 	ksc = g_strdup_printf ("local_%c%c.ksc", tmp[0], tmp[1]);
-	//path = g_build_filename ("/var/games/klavaro/", ksc, NULL);
 	path = g_build_filename (main_path_score (), ksc, NULL);
 	g_free (ksc);
 	g_stat (path, &fs);
@@ -982,568 +991,3 @@ top10_global_publish (gpointer data)
 
 	return FALSE;
 }
-
-#define MAX_KSC_FILES 200
-#define MAX_LANGS 79
-void
-top10_global_rank ()
-{
-	glong i, j, k;
-	gchar *file[MAX_KSC_FILES];
-	glong file_len;
-	gboolean success;
-	gboolean fail;
-	gchar *msg;
-	gchar *tmp;
-	gchar *ksc;
-	gchar *hostsub;
-	gchar *host;
-	gchar *subdir;
-	gchar *user;
-	gchar *pass;
-	gchar *usrpas;
-	gchar *command;
-	gchar *command2;
-	gchar **filelist;
-	gboolean lang_update[MAX_LANGS];
-	FILE *fh;
-	struct stat fs;
-	CURL *curl;
-	CURL *curl2;
-	struct curl_slist *comms = NULL;
-
-	if (!main_curl_ok ())
-	{
-		g_warning ("Not able to upload files: 'libcurl' not installed.");
-		return;
-	}
-
-	host = top10_get_host ();
-	if (host == NULL)
-	{
-		g_message ("Nothing updated");
-		return;
-	}
-
-	user = top10_get_user ("upuser");
-	if (user == NULL)
-	{
-		g_message ("Nothing updated");
-		return;
-	}
-
-	pass = top10_get_pass ("uppass");
-	if (pass == NULL)
-	{
-		g_message ("Nothing updated");
-		return;
-	}
-
-	/* Get listing of files in the upload host
-	 */
-	fail = TRUE;
-	command = g_strdup_printf ("ftp://%s/", host);
-	curl = curl_easy_init ();
-	if (curl)
-	{
-		tmp = g_strconcat (user, ":", pass, NULL);
-		if ( (fh = g_fopen ("/tmp/.listing", "wb")) )
-		{
-			//curl_easy_setopt (curl, CURLOPT_VERBOSE, 1);
-			curl_easy_setopt (curl, CURLOPT_FTPLISTONLY, 1);
-			curl_easy_setopt (curl, CURLOPT_WRITEDATA, fh);
-			curl_easy_setopt (curl, CURLOPT_USERPWD, tmp);
-			curl_easy_setopt (curl, CURLOPT_URL, command);
-			curl_easy_perform (curl);
-			if (curl_easy_perform (curl))
-				g_message ("Retrieving .listing file failed!");
-			else
-				fail = FALSE;
-			fclose (fh);
-		}
-		curl_easy_cleanup (curl);
-		g_free (tmp);
-	}
-
-	g_free (command);
-	if (fail)
-	{
-		g_free (host);
-		g_free (user);
-		g_free (pass);
-		g_warning ("Not able to connect to the uploading host");
-		return;
-	}
-
-	if (!g_file_get_contents ("/tmp/.listing", &tmp, NULL, NULL))
-	{
-		g_free (host);
-		g_free (user);
-		g_free (pass);
-		g_warning ("Not able to get a file list from the uploading host");
-		return;
-	}
-	g_unlink ("/tmp/.listing");
-
-	filelist = g_strsplit_set (tmp, "\n\r", 0);
-	g_free (tmp);
-
-	/* Select which files to download
-	 */
-	fail = FALSE;
-	i = j = k = 0;
-	while (filelist[i])
-	{
-		if (! g_str_has_suffix (filelist[i], ".ksc"))
-		{
-			i++;
-			continue;
-		}
-		for (k = 0; k < j; k++)
-			if (g_str_equal (filelist[i], file[k]))
-			{
-				fail = TRUE;
-				break;
-			}
-		if (fail)
-			break;
-		file[j++] = g_strdup (filelist[i]);
-		if (j == MAX_KSC_FILES)
-		{
-			g_warning ("Maximum number of files to process reached: %li", j);
-			break;
-		}
-		i++;
-	}
-	file_len = j;
-	g_strfreev (filelist);
-
-	/* Download the new files from upload host
-	 */
-	fail = TRUE;
-	msg = g_strconcat (user, ":", pass, NULL);
-	g_free (user);
-       	g_free (pass);
-	if (! (curl = curl_easy_init ()) )
-	{
-		g_free (host);
-		g_free (msg);
-		return;
-	}
-	//curl_easy_setopt (curl, CURLOPT_VERBOSE, 1);
-	curl_easy_setopt (curl, CURLOPT_USERPWD, msg);
-	tmp = g_build_filename (g_get_tmp_dir (), "klavaro", NULL);
-	g_mkdir (tmp, DIR_PERM);
-	g_free (tmp);
-	g_printf ("Downloaded:\n");
-	for (i = 0; i < file_len; i++)
-	{
-		command = g_strdup_printf ("ftp://%s/%s", host, file[i]);
-		tmp = g_build_filename (g_get_tmp_dir (), "klavaro", file[i], NULL);
-		if ( (fh = g_fopen (tmp, "wb")) )
-		{
-			curl_easy_setopt (curl, CURLOPT_URL, command);
-			curl_easy_setopt (curl, CURLOPT_WRITEDATA, fh);
-			curl_easy_perform (curl);
-			fclose (fh);
-			g_printf ("\t%s\n", file[i]);
-		}
-		g_free (tmp);
-		g_free (command);
-	}
-	curl_easy_cleanup (curl);
-	g_free (msg);
-	g_free (host);
-
-	/* Rank local files into global files
-	 */
-	for (i = 0; trans_get_code (i) != NULL && i < MAX_LANGS; i++)
-	{
-		lang_update[i] = FALSE;
-		if (i > 0)
-			if (g_str_equal (trans_get_code (i), trans_get_code (i - 1)))
-				continue;
-
-		top10_read_stats (GLOBAL, i);
-		tmp = g_strconcat ("_", trans_get_code (i), ".ksc", NULL);
-		success = 0;
-		for (j = 0; j < file_len; j++)
-		{
-			if (g_str_has_suffix (file[j], tmp))
-			{
-				ksc = g_build_filename (g_get_tmp_dir (), "klavaro", file[j], NULL);
-				if (!top10_read_stats_from_file (LOCAL, ksc))
-					g_message ("Invalid file: %s", ksc);
-				else
-				{
-					for (k = 0; k < 10; k++)
-					{
-						if (!top10_validate_stat (&top10_local[k]))
-							continue;
-						if (top10_compare_insert_stat (&top10_local[k], GLOBAL))
-						{
-							lang_update[i] = TRUE;
-							success++;
-						}
-					}
-				}
-				msg = g_build_filename (g_get_tmp_dir (), file[j], NULL);
-				if (g_rename (ksc, msg))
-					g_unlink (ksc);
-				g_free (ksc);
-				g_free (msg);
-			}
-		}
-		g_free (tmp);
-		if (success)
-			top10_write_stats (GLOBAL, i);
-	}
-	tmp = g_build_filename (g_get_tmp_dir (), "klavaro", NULL);
-	g_rmdir (tmp);
-	g_free (tmp);
-
-	/* Upload new rankings to download host
-	 */
-	hostsub = top10_get_host ();
-	if (hostsub == NULL)
-	{
-		g_message ("Nothing updated");
-		return;
-	}
-	subdir = strchr (hostsub, '/');
-	if (!subdir)
-		host = g_strdup (hostsub);
-	else
-		host = g_strndup (hostsub, subdir - hostsub);
-	g_free (hostsub);
-
-	user = top10_get_user ("downuser");
-	if (user == NULL)
-	{
-		g_message ("Nothing updated");
-		return;
-	}
-
-	pass = top10_get_pass ("downpass");
-	if (pass == NULL)
-	{
-		g_message ("Nothing updated");
-		return;
-	}
-
-	curl = curl_easy_init ();
-	if (! curl)
-	{
-		g_message ("Nothing updated");
-		g_free (host);
-		g_free (user);
-		g_free (pass);
-		return;
-	}
-	curl_easy_setopt (curl, CURLOPT_UPLOAD, TRUE);
-	curl_easy_setopt (curl, CURLOPT_TIMEOUT, TIMEOUT);
-	curl_easy_setopt (curl, CURLOPT_LOW_SPEED_LIMIT, LOW_SPEED_LIMIT);
-	curl_easy_setopt (curl, CURLOPT_LOW_SPEED_TIME, LOW_SPEED_TIME);
-
-	curl2 = curl_easy_init ();
-	if (!curl2)
-	{
-		g_message ("Nothing updated in the new server");
-		g_free (host);
-		g_free (user);
-		g_free (pass);
-		return;
-	}
-	curl_easy_setopt (curl2, CURLOPT_UPLOAD, TRUE);
-	curl_easy_setopt (curl, CURLOPT_TIMEOUT, TIMEOUT);
-	curl_easy_setopt (curl, CURLOPT_LOW_SPEED_LIMIT, LOW_SPEED_LIMIT);
-	curl_easy_setopt (curl, CURLOPT_LOW_SPEED_TIME, LOW_SPEED_TIME);
-
-	usrpas = g_strdup_printf ("%s:%s", user, pass);
-	curl_easy_setopt (curl, CURLOPT_USERPWD, usrpas);
-	//curl_easy_setopt (curl, CURLOPT_VERBOSE, 1);
-	g_printf ("Uploaded:\n");
-	for (i = 0; trans_get_code (i) != NULL && i < MAX_LANGS; i++)
-	{
-		if (i > 0)
-			if (g_str_equal (trans_get_code (i), trans_get_code (i - 1)))
-				continue;
-		if (lang_update[i] == FALSE)
-			continue;
-
-		msg = g_strconcat ("global_", trans_get_code (i), ".ksc", NULL);
-		ksc = g_build_filename (main_path_score (), msg, NULL);
-		command = g_strdup_printf ("ftp://%s/%s", host, msg);
-		command2 = g_strdup_printf ("http://" CGI_SERVER "?dosiernomo=%s&lingvo=%s", msg, trans_get_code (i));
-		success = FALSE;
-		if ( (fh = g_fopen (ksc, "rb")))
-		{
-			fs.st_size = 0;
-			g_stat (ksc, &fs);
-			curl_easy_setopt (curl, CURLOPT_INFILESIZE, (long) fs.st_size);
-			curl_easy_setopt (curl, CURLOPT_URL, command);
-			curl_easy_setopt (curl, CURLOPT_READDATA, fh);
-			curl_easy_setopt (curl2, CURLOPT_INFILESIZE, (long) fs.st_size);
-			curl_easy_setopt (curl2, CURLOPT_URL, command2);
-			curl_easy_setopt (curl2, CURLOPT_READDATA, fh);
-			if (curl_easy_perform (curl))
-				g_message ("FTP upload failed!");
-			else
-				success = TRUE;
-			fseek (fh, 0, SEEK_SET);
-			curl_easy_perform (curl2);
-			g_printf ("\t%s\n", msg);
-			fclose (fh);
-		}
-		g_free (msg);
-		g_free (ksc);
-		g_free (command);
-		g_free (command2);
-	}
-	curl_easy_cleanup (curl);
-	curl_easy_cleanup (curl2);
-
-	g_free (host);
-	g_free (user);
-	g_free (pass);
-	g_free (usrpas);
-
-	/* Remove downloaded files in uphost
-	 */
-	host = top10_get_host ();
-	if (host == NULL)
-	{
-		g_message ("Nothing updated");
-		return;
-	}
-
-	user = top10_get_user ("upuser");
-	if (user == NULL)
-	{
-		g_message ("Nothing updated");
-		return;
-	}
-
-	pass = top10_get_pass ("uppass");
-	if (pass == NULL)
-	{
-		g_message ("Nothing updated");
-		return;
-	}
-
-	curl = curl_easy_init ();
-	if (! curl)
-	{
-		g_message ("Nothing updated");
-		g_free (host);
-		g_free (user);
-		g_free (pass);
-		return;
-	}
-
-	//curl_easy_setopt (curl, CURLOPT_VERBOSE, 1);
-	for (i = 0; i < file_len; i++)
-	{
-		tmp = g_strdup_printf ("DELE %s", file[i]);
-		comms = curl_slist_append (comms, tmp);
-		g_free (tmp);
-	}
-	usrpas = g_strdup_printf ("%s:%s", user, pass);
-	command = g_strdup_printf ("ftp://%s", host);
-
-	g_printf ("---\nRemaining remotely:\n");
-	curl_easy_setopt (curl, CURLOPT_QUOTE, comms);
-	curl_easy_setopt (curl, CURLOPT_FTPLISTONLY, 1);
-	curl_easy_setopt (curl, CURLOPT_USERPWD, usrpas);
-	curl_easy_setopt (curl, CURLOPT_URL, command);
-	if (curl_easy_perform (curl))
-		g_message ("Remote deletion failed!");
-	curl_easy_cleanup (curl);
-	
-	g_free (host);
-	g_free (user);
-	g_free (pass);
-	g_free (usrpas);
-	g_free (command);
-	curl_slist_free_all (comms);
-}
-
-gchar *
-top10_get_host ()
-{
-	gchar *tmp;
-	gchar *host = NULL;
-
-	if (keyfile == NULL)
-		keyfile = g_key_file_new ();
-
-	top10_keyfile_proverbaro ();
-	host = g_key_file_get_string (keyfile, "proverbo", "kie", NULL);
-
-	tmp = g_strconcat (_("No valid host"), ": ", _("nothing done"), ".", NULL);
-	if (host == NULL)
-		top10_message (tmp);
-	else if (strlen (host) == 0)
-	{
-		top10_message (tmp);
-		g_free (host);
-		host = NULL;
-	}
-	g_free (tmp);
-	return (host);
-}
-
-gchar *
-top10_get_user (gchar * updown)
-{
-	gchar *tmp;
-	gchar *user = NULL;
-	gchar *host = NULL;
-
-	if (keyfile == NULL)
-		keyfile = g_key_file_new ();
-
-	if (top10_keyfile_proverbaro () == FALSE)
-		return (NULL);
-	host = g_key_file_get_string (keyfile, "proverbo", "kie", NULL);
-	if (g_str_equal (updown, "downuser"))
-		user = g_strconcat ("klavaro@", host, NULL);
-	else
-	{
-		tmp = g_key_file_get_string (keyfile, "proverbo", "kiu", NULL);
-		user = g_strconcat (tmp, "@", host, NULL);
-		g_free (tmp);
-	}
-	g_free (host);
-
-	if (user == NULL)
-	{
-		tmp = g_strconcat (_("No valid user is defined"), ": ", _("nothing done"), ".", NULL);
-		top10_message (tmp);
-		g_free (tmp);
-		return (NULL);
-	}
-	else if (strlen (user) == 0)
-	{
-		tmp = g_strconcat (_("No valid user is defined"), ": ", _("nothing done"), ".", NULL);
-		top10_message (tmp);
-		g_free (tmp);
-		g_free (user);
-		return (NULL);
-	}
-	return (user);
-}
-
-gchar *
-top10_get_pass (gchar * updown)
-{
-	gsize i, j;
-	gsize max;
-	gchar *tmp;
-	gchar *pass = NULL;
-	time_t when;
-	struct tm *ltime;
-
-	when = time (NULL);
-	ltime = localtime (&when);
-
-	if (keyfile == NULL)
-		keyfile = g_key_file_new ();
-
-	if (g_str_equal (updown, "downpass"))
-	{
-		tmp = g_build_filename (main_path_user (), "adm.txt", NULL);
-		if (! g_file_get_contents (tmp, &pass, NULL, NULL))
-		{
-			g_free (tmp);
-			g_free (pass);
-			g_message ("You are not the administrator of Klavaro's default host. Nothing done");
-			return (NULL);
-		}
-		g_free (tmp);
-	}
-	else
-	{
-		if (top10_keyfile_proverbaro () == FALSE)
-			return (NULL);
-		tmp = g_key_file_get_string (keyfile, "proverbo", "kiel", NULL);
-		pass = g_strdup (tmp);
-		max = strlen (pass) - 1;
-		for (i = 0, j = 0; i < max; i++)
-		{
-			tmp[j] = pass[i];
-			if (pass[i] == ' ')
-				pass[i + 1] = g_ascii_toupper (pass[i + 1]);
-			else
-				j++;
-		}
-		tmp[j] = pass[i];
-		tmp[j + 1] = '\0';
-		g_free (pass);
-		pass = g_strdup_printf ("%s%i", tmp, ltime->tm_year + 1900);
-		g_free (tmp);
-	}
-
-	if (pass == NULL)
-	{
-		tmp = g_strconcat (_("No valid password is defined"), ": ", _("nothing done"), ".", NULL);
-		top10_message (tmp);
-		g_free (tmp);
-		return (NULL);
-	}
-	if (strlen (pass) == 0)
-	{
-		tmp = g_strconcat (_("No valid password is defined"), ": ", _("nothing done"), ".", NULL);
-		top10_message (tmp);
-		g_free (tmp);
-		g_free (pass);
-		return (NULL);
-	}
-	return (pass);
-}
-
-gboolean
-top10_keyfile_proverbaro ()
-{
-	gchar *tmp;
-	FILE *fh;
-	CURL *curl;
-
-	if (keyfile == NULL)
-		keyfile = g_key_file_new ();
-
-	tmp = g_build_filename (main_path_user (), "proverbaro.desktop", NULL);
-	if (!g_file_test (tmp, G_FILE_TEST_IS_REGULAR))
-	{
-		fh = g_fopen (tmp, "wb");
-		if (!fh)
-		{
-			g_message ("Not able to write to: %s", tmp);
-			g_free (tmp);
-			return FALSE;
-		}
-		if (! (curl = curl_easy_init ()) )
-		{
-			g_message ("Not able to initialize 'curl'");
-			fclose (fh);
-			g_free (tmp);
-			return FALSE;
-		}
-		//curl_easy_setopt (curl, CURLOPT_VERBOSE, 1);
-		curl_easy_setopt (curl, CURLOPT_WRITEDATA, fh);
-		curl_easy_setopt (curl, CURLOPT_URL, "http://klavaro.sourceforge.net/proverbaro.desktop");
-		if (curl_easy_perform (curl))
-		{
-			top10_message (_("Not able to reach default host."));
-			curl_easy_cleanup (curl);
-			fclose (fh);
-			g_free (tmp);
-			return FALSE;
-		}
-		curl_easy_cleanup (curl);
-		fclose (fh);
-	}
-	g_key_file_load_from_file (keyfile, tmp, G_KEY_FILE_NONE, NULL);
-	g_free (tmp);
-	return TRUE;
-}
