@@ -36,12 +36,12 @@ typedef struct STATISTICS
 	gchar lang[2];		// Language code
 	gchar genv;		// Graphical environment: 'x' = X; 'w' = Windows
 	time_t when;		// Epoch of stats logging
-	gint nchars;		// Number of chars typed in the test
+	gint32 nchars;		// Number of chars typed in the test
 	gfloat accur;
 	gfloat velo;
 	gfloat fluid;
 	gfloat score;		// s = f (accur, velo, fluid)
-	gint name_len;
+	gint32 name_len;
 	gchar name[MAX_NAME_LEN + 1];
 } Statistics;
 
@@ -79,15 +79,3 @@ gboolean top10_global_update (gpointer data);
 
 gboolean top10_global_publish (gpointer data);
 
-void top10_global_rank (void);
-
-gchar *top10_get_host ();
-
-gchar *top10_get_user (gchar * updown);
-
-gchar *top10_get_pass (gchar * updown);
-
-gboolean top10_keyfile_proverbaro (void);
-
-gboolean top10_host_test (gpointer data);
-
