@@ -43,21 +43,24 @@ trans_code_to_country (gchar *code)
 	gsize i;
 	gchar *dummy = NULL;
 	static gchar map[COUNTRY_N][2][64] = {
-		{"xx","Esperantujo"},
+		{"xx","Esperantio"},
 		{"ar","العالم العربي"},
 		{"be","België"},
 		{"br","Brasil"},
+		{"ca","Canada"},
 		{"cz","Česká republika"},
 		{"dk","Danmark"},
 		{"de","Deutschland"},
-		{"eo","Esperanto-lando"},
+		{"eo","Esperantujo"},
 		{"es","España"},
+		{"eu","Euskal Herria"},
 		{"fr","France"},
 		{"gr","Ελλάδα"},
 		{"il","ישראל"},
 		{"hu","Magyarország"},
 		{"it","Italia"},
 		{"jp","日本 (Nippon)"},
+		{"kk","Қазақстан"},
 		{"nb","Norge"},
 		{"pl","Polska"},
 		{"pk","پاکستان"},
@@ -68,9 +71,6 @@ trans_code_to_country (gchar *code)
 		{"uk","United Kingdom"},
 		{"us","USA"},
 		{"",""},
-		{"",""},
-		{"",""},
-		{"",""},
 		{"",""}
 	};
 
