@@ -33,8 +33,10 @@
 "English UK (en_GB) [qwerty_uk]\n" \
 "Esperanto (eo) [dvorak_eo_eurokeys]\n" \
 "Español; Castellano (es) [qwerty_es]\n" \
+"Euskara (eu) [qwerty_es]\n" \
 "Français (fr) [azerty_fr]\n" \
 "Galego (gl) [qwerty_es]\n" \
+"Қазақ (kk) [jtsuken_kk]\n" \
 "Magyar (hu) [qwertz_hu]\n" \
 "Nederlands (nl) [qwerty_us]\n" \
 "Polski (pl) [qwertz_pl]\n" \
