@@ -158,7 +158,7 @@ tutor_init (TutorType tt_type)
 	/******************************
 	 * Set the layout for each exercise type
 	 */
-	if (!UNIX_OK)
+	//if (!UNIX_OK)
 		gtk_widget_hide (get_wg ("button_tutor_top10"));
 	gtk_widget_hide (get_wg ("entry_custom_basic_lesson"));
 	if (tutor.type == TT_BASIC || tutor.type == TT_FLUID)
@@ -179,7 +179,7 @@ tutor_init (TutorType tt_type)
 		else
 		{
 			gtk_widget_hide (get_wg ("togglebutton_edit_basic_lesson"));
-			if (UNIX_OK)
+			//if (UNIX_OK)
 				gtk_widget_show (get_wg ("button_tutor_top10"));
 			gtk_widget_hide (get_wg ("button_tutor_show_keyb"));
 			gtk_label_set_text (GTK_LABEL (get_wg ("label_lesson")), _("Paragraphs:"));
@@ -924,7 +924,8 @@ tutor_calc_stats ()
 						g_strdup (_
 							  ("ps.: you have entered the Top 10 list, great!"));
 					top10_write_stats (LOCAL, -1);
-					if (main_preferences_get_boolean ("game", "autopublish") && UNIX_OK)
+					//if (main_preferences_get_boolean ("game", "autopublish") && UNIX_OK)
+					if (main_preferences_get_boolean ("game", "autopublish"))
 					{
 						top10_show_stats (LOCAL);
 						top10_show_stats (GLOBAL);
@@ -1107,7 +1108,7 @@ tutor_calc_stats ()
 
 		if (contest_ps != NULL)
 		{
-			if (UNIX_OK)
+			//if (UNIX_OK)
 			{
 				gtk_text_buffer_insert_at_cursor (buf, "\n", 1);
 				gtk_text_buffer_insert_at_cursor (buf, contest_ps, strlen (contest_ps));
